EntityEmbeddingModel
====================

.. currentmodule:: pykeen.models

.. autoclass:: EntityEmbeddingModel
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~EntityEmbeddingModel.embedding_dim

   .. rubric:: Methods Summary

   .. autosummary::

      ~EntityEmbeddingModel.post_parameter_update

   .. rubric:: Attributes Documentation

   .. autoattribute:: embedding_dim

   .. rubric:: Methods Documentation

   .. automethod:: post_parameter_update
